json_schema_matcher library
Support for doing something awesome.
More dartdocs go here.
Functions
-
isJsonArray(
Map< String, Matcher> itemFieldMatchers, {bool strictFields = false}) → Matcher - Creates a matcher for JSON arrays of objects validation using standard Dart matchers.
-
isJsonArrayOf(
Matcher itemMatcher) → Matcher - Creates a matcher for JSON arrays of primitive types validation using a matcher.
-
isJsonObject(
Map< String, Matcher> fieldMatchers, {bool strictFields = false}) → Matcher - Creates a matcher for JSON objects validation using standard Dart matchers.